==> haskell-tabular-0.2.2.8-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tabular
version:              0.2.2.8
visibility:           public
id:                   tabular-0.2.2.8-95p3h1QIWwyCocci2BuF7w
key:                  tabular-0.2.2.8-95p3h1QIWwyCocci2BuF7w
license:              BSD-3-Clause
maintainer:           Ben Gamari <bgamari@well-typed.com>
author:               Eric Kow
homepage:             https://github.com/bgamari/tabular
synopsis:             Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.

    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.

    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok

category:             Text
abi:                  27c839811fdddefe5b406beb4562dddc
exposed:              True
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tabular-0.2.2.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tabular-0.2.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tabular
hs-libraries:         HStabular-0.2.2.8-95p3h1QIWwyCocci2BuF7w
depends:
    base-4.16.4.0 csv-0.1.2-2mOrtFtvinGFo8c9ncR0hW
    html-1.0.1.2-1i34Da0w7lMJxSeIv8hoxf mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html:         /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tabular-0.2.2.8-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tabular
version:              0.2.2.8
visibility:           public
id:                   tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
key:                  tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
license:              BSD-3-Clause
maintainer:           Ben Gamari <bgamari@well-typed.com>
author:               Eric Kow
homepage:             https://github.com/bgamari/tabular
synopsis:             Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.

    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.

    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok

category:             Text
abi:                  212f0b83976d28c3e1e522988000d063
exposed:              True
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tabular-0.2.2.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tabular-0.2.2.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tabular-0.2.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tabular
hs-libraries:         HStabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
depends:
    base-4.17.2.1 csv-0.1.2-6gshKzmu0tbIbNqFifXYaI
    html-1.0.1.2-J6DAJfvF1D3ECsZlmS8hoI mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html:         /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
